@@ -1,5 +1,5 @@
 package Catalyst::View::JavaScript::Minifier::XS;
-our $VERSION = '1.093030';
+our $VERSION = '1.093180';
 
 
 
@@ -127,7 +127,7 @@ Catalyst::View::JavaScript::Minifier::XS - Minify your served JavaScript files
 
 =head1 VERSION
 
-version 1.093030
+version 1.093180
 
 =head1 SYNOPSIS
 
@@ -138,7 +138,8 @@ version 1.093030
  sub js : Local {
     my ( $self, $c ) = @_;
 
-    $c->stash->{js} = [qw/script1 script2/]; # loads root/js/script1.js and root/js/script2.js
+    # loads root/js/script1.js and root/js/script2.js
+    $c->stash->{js} = [qw/script1 script2/];
 
     $c->forward('View::JavaScript');
  }
@@ -168,16 +169,20 @@ default : js
 
 =item subinclude
 
-setting this to true will take your js files (stash variable) from your referer action
+setting this to true will take your js files (stash variable) from your referer
+action
 
  # in your controller
  sub action : Local {
     my ( $self, $c ) = @_;
 
-    $c->stash->{js} = "exclusive"; # loads exclusive.js only when /action is loaded
+    # load exclusive.js only when /action is loaded
+    $c->stash->{js} = "exclusive";
  }
 
-This could be very dangerous since it's using C<< $c->forward($c->request->headers->referer) >>. It doesn't work with the index action!
+This could be very dangerous since it's using
+C<< $c->forward($c->request->headers->referer) >>. It doesn't work with the
+index action!
 
 default : false
 
